# Stubs for reprlib (Python 3)

from array import array
from typing import Any, Callable, Deque, Dict, FrozenSet, List, Set, Tuple

_ReprFunc = Callable[[Any], str]

def recursive_repr(fillvalue: str = ...) -> Callable[[_ReprFunc], _ReprFunc]: ...

class Repr:
    maxlevel: int
    maxdict: int
    maxlist: int
    maxtuple: int
    maxset: int
    maxfrozenset: int
    maxdeque: int
    maxarray: int
    maxlong: int
    maxstring: int
    maxother: int
    def __init__(self) -> None: ...
    def repr(self, x: Any) -> str: ...
    def repr1(self, x: Any, level: int) -> str: ...
    def repr_tuple(self, x: Tuple[Any, ...], level: int) -> str: ...
    def repr_list(self, x: List[Any], level: int) -> str: ...
    def repr_array(self, x: array[Any], level: int) -> str: ...
    def repr_set(self, x: Set[Any], level: int) -> str: ...
    def repr_frozenset(self, x: FrozenSet[Any], level: int) -> str: ...
    def repr_deque(self, x: Deque[Any], level: int) -> str: ...
    def repr_dict(self, x: Dict[Any, Any], level: int) -> str: ...
    def repr_str(self, x: str, level: int) -> str: ...
    def repr_int(self, x: int, level: int) -> str: ...
    def repr_instance(self, x: Any, level: int) -> str: ...

aRepr: Repr
def repr(x: object) -> str: ...



from io import BytesIO
from types import TracebackType
from typing import Any, Dict, List, Optional, Pattern, Tuple, Type, Union

from django.contrib.auth.models import AbstractUser
from django.contrib.sessions.backends.base import SessionBase
from django.core.handlers.base import BaseHandler
from django.http.cookie import SimpleCookie
from django.http.request import HttpRequest
from django.http.response import HttpResponse, HttpResponseBase

from django.core.handlers.wsgi import WSGIRequest
from json import JSONEncoder

BOUNDARY: str = ...
MULTIPART_CONTENT: str = ...
CONTENT_TYPE_RE: Pattern = ...
JSON_CONTENT_TYPE_RE: Pattern = ...

class RedirectCycleError(Exception):
    last_response: HttpResponseBase = ...
    redirect_chain: List[Tuple[str, int]] = ...
    def __init__(self, message: str, last_response: HttpResponseBase) -> None: ...

class FakePayload:
    read_started: bool = ...
    def __init__(self, content: Optional[Union[bytes, str]] = ...) -> None: ...
    def __len__(self) -> int: ...
    def read(self, num_bytes: int = ...) -> bytes: ...
    def write(self, content: Union[bytes, str]) -> None: ...

class ClientHandler(BaseHandler):
    enforce_csrf_checks: bool = ...
    def __init__(self, enforce_csrf_checks: bool = ..., *args: Any, **kwargs: Any) -> None: ...
    def __call__(self, environ: Dict[str, Any]) -> HttpResponseBase: ...

def encode_multipart(boundary: str, data: Dict[str, Any]) -> bytes: ...
def encode_file(boundary: str, key: str, file: Any) -> List[bytes]: ...

class RequestFactory:
    json_encoder: Type[JSONEncoder]
    defaults: Dict[str, str]
    cookies: SimpleCookie
    errors: BytesIO
    def __init__(self, *, json_encoder: Type[JSONEncoder] = ..., **defaults: Any) -> None: ...
    def request(self, **request: Any) -> WSGIRequest: ...
    def get(self, path: str, data: Any = ..., secure: bool = ..., **extra: Any) -> WSGIRequest: ...
    def post(
        self, path: str, data: Any = ..., content_type: str = ..., secure: bool = ..., **extra: Any
    ) -> WSGIRequest: ...
    def head(self, path: str, data: Any = ..., secure: bool = ..., **extra: Any) -> WSGIRequest: ...
    def trace(self, path: str, secure: bool = ..., **extra: Any) -> WSGIRequest: ...
    def options(
        self,
        path: str,
        data: Union[Dict[str, str], str] = ...,
        content_type: str = ...,
        follow: bool = ...,
        secure: bool = ...,
        **extra: Any
    ) -> WSGIRequest: ...
    def put(
        self, path: str, data: Any = ..., content_type: str = ..., secure: bool = ..., **extra: Any
    ) -> WSGIRequest: ...
    def patch(
        self, path: str, data: Any = ..., content_type: str = ..., secure: bool = ..., **extra: Any
    ) -> WSGIRequest: ...
    def delete(
        self, path: str, data: Any = ..., content_type: str = ..., secure: bool = ..., **extra: Any
    ) -> WSGIRequest: ...
    def generic(
        self,
        method: str,
        path: str,
        data: Any = ...,
        content_type: Optional[str] = ...,
        secure: bool = ...,
        **extra: Any
    ) -> WSGIRequest: ...

class Client(RequestFactory):
    handler: ClientHandler
    raise_request_exception: bool
    exc_info: Optional[Tuple[Type[BaseException], BaseException, TracebackType]]
    def __init__(
        self,
        enforce_csrf_checks: bool = ...,
        raise_request_exception: bool = ...,
        *,
        json_encoder: Type[JSONEncoder] = ...,
        **defaults: Any
    ) -> None: ...
    # Silence type warnings, since this class overrides arguments and return types in an unsafe manner.
    def request(self, **request: Any) -> HttpResponse: ...  # type: ignore
    def get(  # type: ignore
        self, path: str, data: Any = ..., follow: bool = ..., secure: bool = ..., **extra: Any
    ) -> HttpResponse: ...  # type: ignore
    def post(  # type: ignore
        self, path: str, data: Any = ..., content_type: str = ..., follow: bool = ..., secure: bool = ..., **extra: Any
    ) -> HttpResponse: ...  # type: ignore
    def head(  # type: ignore
        self, path: str, data: Any = ..., follow: bool = ..., secure: bool = ..., **extra: Any
    ) -> HttpResponse: ...  # type: ignore
    def trace(  # type: ignore
        self, path: str, follow: bool = ..., secure: bool = ..., **extra: Any
    ) -> HttpResponse: ...  # type: ignore
    def options(  # type: ignore
        self,
        path: str,
        data: Union[Dict[str, str], str] = ...,
        content_type: str = ...,
        follow: bool = ...,
        secure: bool = ...,
        **extra: Any
    ) -> HttpResponse: ...  # type: ignore
    def put(  # type: ignore
        self, path: str, data: Any = ..., content_type: str = ..., follow: bool = ..., secure: bool = ..., **extra: Any
    ) -> HttpResponse: ...  # type: ignore
    def patch(  # type: ignore
        self, path: str, data: Any = ..., content_type: str = ..., follow: bool = ..., secure: bool = ..., **extra: Any
    ) -> HttpResponse: ...  # type: ignore
    def delete(  # type: ignore
        self, path: str, data: Any = ..., content_type: str = ..., follow: bool = ..., secure: bool = ..., **extra: Any
    ) -> HttpResponse: ...  # type: ignore
    def store_exc_info(self, **kwargs: Any) -> None: ...
    @property
    def session(self) -> SessionBase: ...
    def login(self, **credentials: Any) -> bool: ...
    def force_login(self, user: AbstractUser, backend: Optional[str] = ...) -> None: ...
    def logout(self) -> None: ...

def conditional_content_removal(request: HttpRequest, response: HttpResponseBase) -> HttpResponse: ...



from .base import RedirectView as RedirectView, TemplateView as TemplateView, View as View
from .dates import (
    ArchiveIndexView as ArchiveIndexView,
    DateDetailView as DateDetailView,
    DayArchiveView as DayArchiveView,
    MonthArchiveView as MonthArchiveView,
    TodayArchiveView as TodayArchiveView,
    WeekArchiveView as WeekArchiveView,
    YearArchiveView as YearArchiveView,
)
from .detail import DetailView as DetailView
from .edit import CreateView as CreateView, DeleteView as DeleteView, FormView as FormView, UpdateView as UpdateView
from .list import ListView as ListView

class GenericViewError(Exception): ...



import sys
from typing import Any, Dict, List, Optional, Tuple, Type, Union, overload

if sys.version_info >= (3, 0):
    _defaultaction: str
    _onceregistry: Dict[Any, Any]
else:
    default_action: str
    once_registry: Dict[Any, Any]
filters: List[Tuple[Any, ...]]
@overload
def warn(message: str, category: Optional[Type[Warning]] = ..., stacklevel: int = ...) -> None: ...
@overload
def warn(message: Warning, category: Any = ..., stacklevel: int = ...) -> None: ...
@overload
def warn_explicit(
    message: str,
    category: Type[Warning],
    filename: str,
    lineno: int,
    module: Optional[str] = ...,
    registry: Optional[Dict[Union[str, Tuple[str, Type[Warning], int]], int]] = ...,
    module_globals: Optional[Dict[str, Any]] = ...,
) -> None: ...
@overload
def warn_explicit(
    message: Warning,
    category: Any,
    filename: str,
    lineno: int,
    module: Optional[str] = ...,
    registry: Optional[Dict[Union[str, Tuple[str, Type[Warning], int]], int]] = ...,
    module_globals: Optional[Dict[str, Any]] = ...,
) -> None: ...



import sys
from typing import Any, Mapping, List, Optional, Tuple
from asyncio.protocols import BaseProtocol
from asyncio.events import AbstractEventLoop

class BaseTransport:
    def __init__(self, extra: Mapping[Any, Any] = ...) -> None: ...
    def get_extra_info(self, name: Any, default: Any = ...) -> Any: ...
    def is_closing(self) -> bool: ...
    def close(self) -> None: ...
    if sys.version_info >= (3, 5):
        def set_protocol(self, protocol: BaseProtocol) -> None: ...
        def get_protocol(self) -> BaseProtocol: ...

class ReadTransport(BaseTransport):
    if sys.version_info >= (3, 7):
        def is_reading(self) -> bool: ...
    def pause_reading(self) -> None: ...
    def resume_reading(self) -> None: ...

class WriteTransport(BaseTransport):
    def set_write_buffer_limits(
        self, high: int = ..., low: int = ...
    ) -> None: ...
    def get_write_buffer_size(self) -> int: ...
    def write(self, data: Any) -> None: ...
    def writelines(self, list_of_data: List[Any]) -> None: ...
    def write_eof(self) -> None: ...
    def can_write_eof(self) -> bool: ...
    def abort(self) -> None: ...

class Transport(ReadTransport, WriteTransport): ...

class DatagramTransport(BaseTransport):
    def sendto(self, data: Any, addr: Optional[Tuple[str, int]] = ...) -> None: ...
    def abort(self) -> None: ...

class SubprocessTransport(BaseTransport):
    def get_pid(self) -> int: ...
    def get_returncode(self) -> int: ...
    def get_pipe_transport(self, fd: int) -> BaseTransport: ...
    def send_signal(self, signal: int) -> int: ...
    def terminate(self) -> None: ...
    def kill(self) -> None: ...

class _FlowControlMixin(Transport):
    def __init__(self, extra: Optional[Mapping[Any, Any]] = ..., loop: Optional[AbstractEventLoop] = ...) -> None: ...
    def get_write_buffer_limits(self) -> Tuple[int, int]: ...



from typing import Any, Optional, Sequence, Tuple, Type, TypeVar

from django.db.backends.base.schema import BaseDatabaseSchemaEditor
from django.db.models.base import Model
from django.db.models.query_utils import Q

_T = TypeVar("_T", bound="BaseConstraint")

class BaseConstraint:
    name: str
    def __init__(self, name: str) -> None: ...
    def constraint_sql(
        self, model: Optional[Type[Model]], schema_editor: Optional[BaseDatabaseSchemaEditor]
    ) -> str: ...
    def create_sql(self, model: Optional[Type[Model]], schema_editor: Optional[BaseDatabaseSchemaEditor]) -> str: ...
    def remove_sql(self, model: Optional[Type[Model]], schema_editor: Optional[BaseDatabaseSchemaEditor]) -> str: ...
    def deconstruct(self) -> Any: ...
    def clone(self: _T) -> _T: ...

class CheckConstraint(BaseConstraint):
    check: Q
    def __init__(self, *, check: Q, name: str) -> None: ...

class UniqueConstraint(BaseConstraint):
    fields: Tuple[str]
    condition: Optional[Q]
    def __init__(self, *, fields: Sequence[str], name: str, condition: Optional[Q] = ...): ...



from typing import Any, Dict, List, Mapping, Optional, Sequence
from types import ModuleType

WINEXE: bool
WINSERVICE: bool

def set_executable(exe: str) -> None: ...
def get_executable() -> str: ...
def is_forking(argv: Sequence[str]) -> bool: ...
def freeze_support() -> None: ...
def get_command_line(**kwds: Any) -> List[str]: ...
def spawn_main(pipe_handle: int, parent_pid: Optional[int] = ..., tracker_fd: Optional[int] = ...) -> None: ...
# undocumented
def _main(fd: int) -> Any: ...
def get_preparation_data(name: str) -> Dict[str, Any]: ...
old_main_modules: List[ModuleType]
def prepare(data: Mapping[str, Any]) -> None: ...
def import_main_path(main_path: str) -> None: ...



from collections import OrderedDict
from typing import Any, List, Tuple, Type, Iterable

from django.db.models.expressions import Expression
from django.db.models.lookups import (
    BuiltinLookup,
    Exact,
    GreaterThan,
    GreaterThanOrEqual,
    In,
    IsNull,
    LessThan,
    LessThanOrEqual,
)

from django.db.models.fields import Field

class MultiColSource:
    alias: str
    field: Field
    sources: Tuple[Field, Field]
    targets: Tuple[Field, Field]
    contains_aggregate: bool = ...
    output_field: Field = ...
    def __init__(
        self, alias: str, targets: Tuple[Field, Field], sources: Tuple[Field, Field], field: Field
    ) -> None: ...
    def relabeled_clone(self, relabels: OrderedDict) -> MultiColSource: ...
    def get_lookup(self, lookup: str) -> Type[BuiltinLookup]: ...

def get_normalized_value(value: Any, lhs: Expression) -> Tuple[None]: ...

class RelatedIn(In):
    bilateral_transforms: List[Any]
    lhs: Expression
    rhs: Any = ...
    def get_prep_lookup(self) -> Iterable[Any]: ...

class RelatedLookupMixin:
    rhs: Any = ...
    def get_prep_lookup(self) -> Any: ...

class RelatedExact(RelatedLookupMixin, Exact): ...
class RelatedLessThan(RelatedLookupMixin, LessThan): ...
class RelatedGreaterThan(RelatedLookupMixin, GreaterThan): ...
class RelatedGreaterThanOrEqual(RelatedLookupMixin, GreaterThanOrEqual): ...
class RelatedLessThanOrEqual(RelatedLookupMixin, LessThanOrEqual): ...
class RelatedIsNull(RelatedLookupMixin, IsNull): ...



from typing import Any, Dict, Optional, Tuple, Union
from uuid import UUID

from django.contrib.admin.sites import AdminSite
from django.db.models.fields.reverse_related import ForeignObjectRel, ManyToOneRel
from django.forms.models import ModelChoiceIterator
from django.forms.widgets import Media

from django import forms

class FilteredSelectMultiple(forms.SelectMultiple):
    @property
    def media(self) -> Media: ...
    verbose_name: Any = ...
    is_stacked: Any = ...
    def __init__(self, verbose_name: str, is_stacked: bool, attrs: None = ..., choices: Tuple = ...) -> None: ...

class AdminDateWidget(forms.DateInput):
    @property
    def media(self) -> Media: ...

class AdminTimeWidget(forms.TimeInput):
    @property
    def media(self) -> Media: ...

class AdminSplitDateTime(forms.SplitDateTimeWidget): ...
class AdminRadioSelect(forms.RadioSelect): ...
class AdminFileWidget(forms.ClearableFileInput): ...

def url_params_from_lookup_dict(lookups: Any) -> Dict[str, str]: ...

class ForeignKeyRawIdWidget(forms.TextInput):
    rel: ManyToOneRel = ...
    admin_site: AdminSite = ...
    db: None = ...
    def __init__(self, rel: ForeignObjectRel, admin_site: AdminSite, attrs: None = ..., using: None = ...) -> None: ...
    def base_url_parameters(self) -> Dict[str, str]: ...
    def url_parameters(self) -> Dict[str, str]: ...
    def label_and_url_for_value(self, value: Union[int, str, UUID]) -> Tuple[str, str]: ...

class ManyToManyRawIdWidget(ForeignKeyRawIdWidget): ...

class RelatedFieldWidgetWrapper(forms.Widget):
    template_name: str = ...
    choices: ModelChoiceIterator = ...
    widget: forms.Widget = ...
    rel: ManyToOneRel = ...
    can_add_related: bool = ...
    can_change_related: bool = ...
    can_delete_related: bool = ...
    can_view_related: bool = ...
    admin_site: AdminSite = ...
    def __init__(
        self,
        widget: forms.Widget,
        rel: ForeignObjectRel,
        admin_site: AdminSite,
        can_add_related: Optional[bool] = ...,
        can_change_related: bool = ...,
        can_delete_related: bool = ...,
        can_view_related: bool = ...,
    ) -> None: ...
    @property
    def media(self) -> Media: ...
    def get_related_url(self, info: Tuple[str, str], action: str, *args: Any) -> str: ...

class AdminTextareaWidget(forms.Textarea): ...
class AdminTextInputWidget(forms.TextInput): ...
class AdminEmailInputWidget(forms.EmailInput): ...
class AdminURLFieldWidget(forms.URLInput): ...

class AdminIntegerFieldWidget(forms.NumberInput):
    class_name: str = ...

class AdminBigIntegerFieldWidget(AdminIntegerFieldWidget): ...

class AdminUUIDInputWidget(forms.TextInput):
    def __init__(self, attrs: Optional[Dict[str, str]] = ...) -> None: ...

SELECT2_TRANSLATIONS: Any

class AutocompleteMixin:
    url_name: str = ...
    rel: Any = ...
    admin_site: Any = ...
    db: Any = ...
    choices: Any = ...
    attrs: Any = ...
    def __init__(
        self,
        rel: ForeignObjectRel,
        admin_site: AdminSite,
        attrs: Optional[Dict[str, str]] = ...,
        choices: Tuple = ...,
        using: None = ...,
    ) -> None: ...
    def get_url(self) -> str: ...
    @property
    def media(self) -> Media: ...

class AutocompleteSelect(AutocompleteMixin, forms.Select): ...
class AutocompleteSelectMultiple(AutocompleteMixin, forms.SelectMultiple): ...



from abc import ABCMeta, abstractmethod

from cryptography.hazmat.primitives.serialization import Encoding, KeySerializationEncryption, PrivateFormat, PublicFormat

class Ed25519PrivateKey(metaclass=ABCMeta):
    @classmethod
    def generate(cls) -> Ed25519PrivateKey: ...
    @classmethod
    def from_private_bytes(cls, data: bytes) -> Ed25519PrivateKey: ...
    @abstractmethod
    def private_bytes(
        self, encoding: Encoding, format: PrivateFormat, encryption_algorithm: KeySerializationEncryption
    ) -> bytes: ...
    @abstractmethod
    def public_key(self) -> Ed25519PublicKey: ...
    @abstractmethod
    def sign(self, data: bytes) -> bytes: ...

class Ed25519PublicKey(metaclass=ABCMeta):
    @classmethod
    def from_public_bytes(cls, data: bytes) -> Ed25519PublicKey: ...
    @abstractmethod
    def public_bytes(self, encoding: Encoding, format: PublicFormat) -> bytes: ...
    @abstractmethod
    def verify(self, signature: bytes, data: bytes) -> None: ...



from typing import Any, Callable

from django.http.request import HttpRequest
from django.http.response import HttpResponse
from django.urls.resolvers import URLResolver

def convert_exception_to_response(get_response: Callable) -> Callable: ...
def response_for_exception(request: HttpRequest, exc: Exception) -> HttpResponse: ...
def get_exception_response(
    request: HttpRequest, resolver: URLResolver, status_code: int, exception: Exception, sender: None = ...
) -> HttpResponse: ...
def handle_uncaught_exception(request: Any, resolver: Any, exc_info: Any): ...



class FrozenInstanceError(AttributeError):
    msg: str = ...

class AttrsAttributeNotFoundError(ValueError): ...
class NotAnAttrsClassError(ValueError): ...
class DefaultAlreadySetError(RuntimeError): ...
class UnannotatedAttributeError(RuntimeError): ...



# https://github.com/ijl/orjson/blob/master/orjson.pyi

from typing import Any, Callable, Optional, Union

__version__ = str

def dumps(
    __obj: Any,
    default: Optional[Callable[[Any], Any]] = ...,
    option: Optional[int] = ...,
) -> bytes: ...
def loads(__obj: Union[bytes, bytearray, str]) -> Any: ...

class JSONDecodeError(ValueError): ...
class JSONEncodeError(TypeError): ...

OPT_SERIALIZE_DATACLASS: int
OPT_NAIVE_UTC: int
OPT_OMIT_MICROSECONDS: int
OPT_STRICT_INTEGER: int



"""
This file is about errors in Python files and not about exception handling in
Jedi.
"""


def parso_to_jedi_errors(grammar, module_node):
    return [SyntaxError(e) for e in grammar.iter_errors(module_node)]


class SyntaxError(object):
    """
    Syntax errors are generated by :meth:`.Script.get_syntax_errors`.
    """
    def __init__(self, parso_error):
        self._parso_error = parso_error

    @property
    def line(self):
        """The line where the error starts (starting with 1)."""
        return self._parso_error.start_pos[0]

    @property
    def column(self):
        """The column where the error starts (starting with 0)."""
        return self._parso_error.start_pos[1]

    @property
    def until_line(self):
        """The line where the error ends (starting with 1)."""
        return self._parso_error.end_pos[0]

    @property
    def until_column(self):
        """The column where the error ends (starting with 0)."""
        return self._parso_error.end_pos[1]

    def get_message(self):
        return self._parso_error.message

    def __repr__(self):
        return '<%s from=%s to=%s>' % (
            self.__class__.__name__,
            self._parso_error.start_pos,
            self._parso_error.end_pos,
        )



# Stubs for imp (Python 3.6)

import os
import sys
import types
from typing import Any, IO, List, Optional, Tuple, TypeVar, Union

from _imp import (lock_held as lock_held, acquire_lock as acquire_lock, release_lock as release_lock,
                  get_frozen_object as get_frozen_object, is_frozen_package as is_frozen_package,
                  init_frozen as init_frozen, is_builtin as is_builtin, is_frozen as is_frozen)

from _imp import create_dynamic as create_dynamic

_T = TypeVar('_T')

if sys.version_info >= (3, 6):
    _Path = Union[str, os.PathLike[str]]
else:
    _Path = str

SEARCH_ERROR: int
PY_SOURCE: int
PY_COMPILED: int
C_EXTENSION: int
PY_RESOURCE: int
PKG_DIRECTORY: int
C_BUILTIN: int
PY_FROZEN: int
PY_CODERESOURCE: int
IMP_HOOK: int

def new_module(name: str) -> types.ModuleType: ...
def get_magic() -> bytes: ...
def get_tag() -> str: ...
def cache_from_source(path: _Path, debug_override: Optional[bool] = ...) -> str: ...
def source_from_cache(path: _Path) -> str: ...
def get_suffixes() -> List[Tuple[str, str, int]]: ...

class NullImporter:
    def __init__(self, path: _Path) -> None: ...
    def find_module(self, fullname: Any) -> None: ...

# PathLike doesn't work for the pathname argument here
def load_source(name: str, pathname: str, file: Optional[IO[Any]] = ...) -> types.ModuleType: ...
def load_compiled(name: str, pathname: str, file: Optional[IO[Any]] = ...) -> types.ModuleType: ...
def load_package(name: str, path: _Path) -> types.ModuleType: ...
def load_module(name: str, file: IO[Any], filename: str, details: Tuple[str, str, int]) -> types.ModuleType: ...
if sys.version_info >= (3, 6):
    def find_module(name: str, path: Union[None, List[str], List[os.PathLike[str]], List[_Path]] = ...) -> Tuple[IO[Any], str, Tuple[str, str, int]]: ...
else:
    def find_module(name: str, path: Optional[List[str]] = ...) -> Tuple[IO[Any], str, Tuple[str, str, int]]: ...
def reload(module: types.ModuleType) -> types.ModuleType: ...
def init_builtin(name: str) -> Optional[types.ModuleType]: ...
def load_dynamic(name: str, path: str, file: Optional[IO[Any]] = ...) -> types.ModuleType: ...



# Stubs for resource

# NOTE: These are incomplete!

from typing import Tuple, Optional, NamedTuple

RLIMIT_AS: int
RLIMIT_CORE: int
RLIMIT_CPU: int
RLIMIT_DATA: int
RLIMIT_FSIZE: int
RLIMIT_MEMLOCK: int
RLIMIT_MSGQUEUE: int
RLIMIT_NICE: int
RLIMIT_NOFILE: int
RLIMIT_NPROC: int
RLIMIT_OFILE: int
RLIMIT_RSS: int
RLIMIT_RTPRIO: int
RLIMIT_RTTIME: int
RLIMIT_SIGPENDING: int
RLIMIT_STACK: int
RLIM_INFINITY: int
RUSAGE_CHILDREN: int
RUSAGE_SELF: int
RUSAGE_THREAD: int

class _RUsage(NamedTuple):
    ru_utime: float
    ru_stime: float
    ru_maxrss: int
    ru_ixrss: int
    ru_idrss: int
    ru_isrss: int
    ru_minflt: int
    ru_majflt: int
    ru_nswap: int
    ru_inblock: int
    ru_oublock: int
    ru_msgsnd: int
    ru_msgrcv: int
    ru_nsignals: int
    ru_nvcsw: int
    ru_nivcsw: int

def getpagesize() -> int: ...
def getrlimit(resource: int) -> Tuple[int, int]: ...
def getrusage(who: int) -> _RUsage: ...
def prlimit(pid: int, resource: int, limits: Optional[Tuple[int, int]]) -> Tuple[int, int]: ...
def setrlimit(resource: int, limits: Tuple[int, int]) -> None: ...

# NOTE: This is an alias of OSError in Python 3.3.
class error(Exception): ...



from typing import Any, List

from django.core.management.color import Style

def sql_flush(
    style: Style, connection: Any, only_django: bool = ..., reset_sequences: bool = ..., allow_cascade: bool = ...
) -> List[str]: ...
def emit_pre_migrate_signal(verbosity: int, interactive: bool, db: str, **kwargs: Any) -> None: ...
def emit_post_migrate_signal(verbosity: int, interactive: bool, db: str, **kwargs: Any) -> None: ...



from typing import List, NamedTuple, Optional, overload, TextIO, Type
from types import ModuleType, TracebackType
from typing_extensions import Literal

from _warnings import warn as warn, warn_explicit as warn_explicit

def showwarning(
    message: str, category: Type[Warning], filename: str, lineno: int, file: Optional[TextIO] = ..., line: Optional[str] = ...
) -> None: ...
def formatwarning(message: str, category: Type[Warning], filename: str, lineno: int, line: Optional[str] = ...) -> str: ...
def filterwarnings(
    action: str, message: str = ..., category: Type[Warning] = ..., module: str = ..., lineno: int = ..., append: bool = ...
) -> None: ...
def simplefilter(action: str, category: Type[Warning] = ..., lineno: int = ..., append: bool = ...) -> None: ...
def resetwarnings() -> None: ...

class _Record(NamedTuple):
    message: str
    category: Type[Warning]
    filename: str
    lineno: int
    file: Optional[TextIO]
    line: Optional[str]

class catch_warnings:
    @overload
    def __new__(cls, *, record: Literal[False] = ..., module: Optional[ModuleType] = ...) -> _catch_warnings_without_records: ...
    @overload
    def __new__(cls, *, record: Literal[True], module: Optional[ModuleType] = ...) -> _catch_warnings_with_records: ...
    @overload
    def __new__(cls, *, record: bool, module: Optional[ModuleType] = ...) -> catch_warnings: ...
    def __enter__(self) -> Optional[List[_Record]]: ...
    def __exit__(
        self, exc_type: Optional[Type[BaseException]], exc_val: Optional[BaseException], exc_tb: Optional[TracebackType]
    ) -> None: ...

class _catch_warnings_without_records(catch_warnings):
    def __enter__(self) -> None: ...

class _catch_warnings_with_records(catch_warnings):
    def __enter__(self) -> List[_Record]: ...



from typing import Any

from django.core.management.base import BaseCommand

class TemplateCommand(BaseCommand):
    url_schemes: Any = ...
    rewrite_template_suffixes: Any = ...
    app_or_project: Any = ...
    paths_to_remove: Any = ...
    verbosity: Any = ...
    def handle_template(self, template: Any, subdir: Any): ...
    def validate_name(self, name: Any, app_or_project: Any) -> None: ...
    def download(self, url: Any): ...
    def splitext(self, the_path: Any): ...
    def extract(self, filename: Any): ...
    def is_url(self, template: Any): ...
    def make_writeable(self, filename: Any) -> None: ...



import collections
from datetime import datetime
from typing import Any, Callable, Dict, List, Optional, Sequence, Set, Tuple, Type, Union
from uuid import UUID

from django.contrib.admin.options import BaseModelAdmin
from django.contrib.admin.sites import AdminSite
from django.contrib.auth.forms import AdminPasswordChangeForm
from django.core.handlers.wsgi import WSGIRequest
from django.db.models.base import Model
from django.db.models.deletion import Collector
from django.db.models.fields.reverse_related import ManyToOneRel
from django.db.models.options import Options
from django.db.models.query import QuerySet
from django.forms.forms import BaseForm

from django.db.models.fields import Field, reverse_related

class FieldIsAForeignKeyColumnName(Exception): ...

def lookup_needs_distinct(opts: Options, lookup_path: str) -> bool: ...
def prepare_lookup_value(key: str, value: Union[datetime, str]) -> Union[bool, datetime, str]: ...
def quote(s: Union[int, str, UUID]) -> str: ...
def unquote(s: str) -> str: ...
def flatten(fields: Any) -> List[Union[Callable, str]]: ...
def flatten_fieldsets(fieldsets: Any) -> List[Union[Callable, str]]: ...
def get_deleted_objects(
    objs: Sequence[Optional[Model]], request: WSGIRequest, admin_site: AdminSite
) -> Tuple[List[Any], Dict[Any, Any], Set[Any], List[Any]]: ...

class NestedObjects(Collector):
    data: collections.OrderedDict
    dependencies: Dict[Any, Any]
    fast_deletes: List[Any]
    field_updates: Dict[Any, Any]
    using: str
    edges: Any = ...
    protected: Any = ...
    model_objs: Any = ...
    def __init__(self, *args: Any, **kwargs: Any) -> None: ...
    def add_edge(self, source: Optional[Model], target: Model) -> None: ...
    def related_objects(self, related: ManyToOneRel, objs: Sequence[Optional[Model]]) -> QuerySet: ...
    def nested(self, format_callback: Callable = ...) -> List[Any]: ...

def model_format_dict(obj: Any): ...
def model_ngettext(obj: Union[Options, QuerySet], n: Optional[int] = ...) -> str: ...
def lookup_field(
    name: Union[Callable, str], obj: Model, model_admin: BaseModelAdmin = ...
) -> Tuple[Optional[Field], Any, Any]: ...
def label_for_field(
    name: Union[Callable, str],
    model: Type[Model],
    model_admin: Optional[BaseModelAdmin] = ...,
    return_attr: bool = ...,
    form: Optional[BaseForm] = ...,
) -> Union[Tuple[Optional[str], Union[Callable, Type[str]]], str]: ...
def help_text_for_field(name: str, model: Type[Model]) -> str: ...
def display_for_field(value: Any, field: Field, empty_value_display: str) -> str: ...
def display_for_value(value: Any, empty_value_display: str, boolean: bool = ...) -> str: ...

class NotRelationField(Exception): ...

def get_model_from_relation(field: Union[Field, reverse_related.ForeignObjectRel]) -> Type[Model]: ...
def reverse_field_path(model: Type[Model], path: str) -> Tuple[Type[Model], str]: ...
def get_fields_from_path(model: Type[Model], path: str) -> List[Field]: ...
def construct_change_message(
    form: AdminPasswordChangeForm, formsets: None, add: bool
) -> List[Dict[str, Dict[str, List[str]]]]: ...



ERROR_FIRST: int
HASHCHK: int
NISAMCHK: int
NO: int
YES: int
CANT_CREATE_FILE: int
CANT_CREATE_TABLE: int
CANT_CREATE_DB: int
DB_CREATE_EXISTS: int
DB_DROP_EXISTS: int
DB_DROP_DELETE: int
DB_DROP_RMDIR: int
CANT_DELETE_FILE: int
CANT_FIND_SYSTEM_REC: int
CANT_GET_STAT: int
CANT_GET_WD: int
CANT_LOCK: int
CANT_OPEN_FILE: int
FILE_NOT_FOUND: int
CANT_READ_DIR: int
CANT_SET_WD: int
CHECKREAD: int
DISK_FULL: int
DUP_KEY: int
ERROR_ON_CLOSE: int
ERROR_ON_READ: int
ERROR_ON_RENAME: int
ERROR_ON_WRITE: int
FILE_USED: int
FILSORT_ABORT: int
FORM_NOT_FOUND: int
GET_ERRNO: int
ILLEGAL_HA: int
KEY_NOT_FOUND: int
NOT_FORM_FILE: int
NOT_KEYFILE: int
OLD_KEYFILE: int
OPEN_AS_READONLY: int
OUTOFMEMORY: int
OUT_OF_SORTMEMORY: int
UNEXPECTED_EOF: int
CON_COUNT_ERROR: int
OUT_OF_RESOURCES: int
BAD_HOST_ERROR: int
HANDSHAKE_ERROR: int
DBACCESS_DENIED_ERROR: int
ACCESS_DENIED_ERROR: int
NO_DB_ERROR: int
UNKNOWN_COM_ERROR: int
BAD_NULL_ERROR: int
BAD_DB_ERROR: int
TABLE_EXISTS_ERROR: int
BAD_TABLE_ERROR: int
NON_UNIQ_ERROR: int
SERVER_SHUTDOWN: int
BAD_FIELD_ERROR: int
WRONG_FIELD_WITH_GROUP: int
WRONG_GROUP_FIELD: int
WRONG_SUM_SELECT: int
WRONG_VALUE_COUNT: int
TOO_LONG_IDENT: int
DUP_FIELDNAME: int
DUP_KEYNAME: int
DUP_ENTRY: int
WRONG_FIELD_SPEC: int
PARSE_ERROR: int
EMPTY_QUERY: int
NONUNIQ_TABLE: int
INVALID_DEFAULT: int
MULTIPLE_PRI_KEY: int
TOO_MANY_KEYS: int
TOO_MANY_KEY_PARTS: int
TOO_LONG_KEY: int
KEY_COLUMN_DOES_NOT_EXITS: int
BLOB_USED_AS_KEY: int
TOO_BIG_FIELDLENGTH: int
WRONG_AUTO_KEY: int
READY: int
NORMAL_SHUTDOWN: int
GOT_SIGNAL: int
SHUTDOWN_COMPLETE: int
FORCING_CLOSE: int
IPSOCK_ERROR: int
NO_SUCH_INDEX: int
WRONG_FIELD_TERMINATORS: int
BLOBS_AND_NO_TERMINATED: int
TEXTFILE_NOT_READABLE: int
FILE_EXISTS_ERROR: int
LOAD_INFO: int
ALTER_INFO: int
WRONG_SUB_KEY: int
CANT_REMOVE_ALL_FIELDS: int
CANT_DROP_FIELD_OR_KEY: int
INSERT_INFO: int
UPDATE_TABLE_USED: int
NO_SUCH_THREAD: int
KILL_DENIED_ERROR: int
NO_TABLES_USED: int
TOO_BIG_SET: int
NO_UNIQUE_LOGFILE: int
TABLE_NOT_LOCKED_FOR_WRITE: int
TABLE_NOT_LOCKED: int
BLOB_CANT_HAVE_DEFAULT: int
WRONG_DB_NAME: int
WRONG_TABLE_NAME: int
TOO_BIG_SELECT: int
UNKNOWN_ERROR: int
UNKNOWN_PROCEDURE: int
WRONG_PARAMCOUNT_TO_PROCEDURE: int
WRONG_PARAMETERS_TO_PROCEDURE: int
UNKNOWN_TABLE: int
FIELD_SPECIFIED_TWICE: int
INVALID_GROUP_FUNC_USE: int
UNSUPPORTED_EXTENSION: int
TABLE_MUST_HAVE_COLUMNS: int
RECORD_FILE_FULL: int
UNKNOWN_CHARACTER_SET: int
TOO_MANY_TABLES: int
TOO_MANY_FIELDS: int
TOO_BIG_ROWSIZE: int
STACK_OVERRUN: int
WRONG_OUTER_JOIN: int
NULL_COLUMN_IN_INDEX: int
CANT_FIND_UDF: int
CANT_INITIALIZE_UDF: int
UDF_NO_PATHS: int
UDF_EXISTS: int
CANT_OPEN_LIBRARY: int
CANT_FIND_DL_ENTRY: int
FUNCTION_NOT_DEFINED: int
HOST_IS_BLOCKED: int
HOST_NOT_PRIVILEGED: int
PASSWORD_ANONYMOUS_USER: int
PASSWORD_NOT_ALLOWED: int
PASSWORD_NO_MATCH: int
UPDATE_INFO: int
CANT_CREATE_THREAD: int
WRONG_VALUE_COUNT_ON_ROW: int
CANT_REOPEN_TABLE: int
INVALID_USE_OF_NULL: int
REGEXP_ERROR: int
MIX_OF_GROUP_FUNC_AND_FIELDS: int
NONEXISTING_GRANT: int
TABLEACCESS_DENIED_ERROR: int
COLUMNACCESS_DENIED_ERROR: int
ILLEGAL_GRANT_FOR_TABLE: int
GRANT_WRONG_HOST_OR_USER: int
NO_SUCH_TABLE: int
NONEXISTING_TABLE_GRANT: int
NOT_ALLOWED_COMMAND: int
SYNTAX_ERROR: int
DELAYED_CANT_CHANGE_LOCK: int
TOO_MANY_DELAYED_THREADS: int
ABORTING_CONNECTION: int
NET_PACKET_TOO_LARGE: int
NET_READ_ERROR_FROM_PIPE: int
NET_FCNTL_ERROR: int
NET_PACKETS_OUT_OF_ORDER: int
NET_UNCOMPRESS_ERROR: int
NET_READ_ERROR: int
NET_READ_INTERRUPTED: int
NET_ERROR_ON_WRITE: int
NET_WRITE_INTERRUPTED: int
TOO_LONG_STRING: int
TABLE_CANT_HANDLE_BLOB: int
TABLE_CANT_HANDLE_AUTO_INCREMENT: int
DELAYED_INSERT_TABLE_LOCKED: int
WRONG_COLUMN_NAME: int
WRONG_KEY_COLUMN: int
WRONG_MRG_TABLE: int
DUP_UNIQUE: int
BLOB_KEY_WITHOUT_LENGTH: int
PRIMARY_CANT_HAVE_NULL: int
TOO_MANY_ROWS: int
REQUIRES_PRIMARY_KEY: int
NO_RAID_COMPILED: int
UPDATE_WITHOUT_KEY_IN_SAFE_MODE: int
KEY_DOES_NOT_EXITS: int
CHECK_NO_SUCH_TABLE: int
CHECK_NOT_IMPLEMENTED: int
CANT_DO_THIS_DURING_AN_TRANSACTION: int
ERROR_DURING_COMMIT: int
ERROR_DURING_ROLLBACK: int
ERROR_DURING_FLUSH_LOGS: int
ERROR_DURING_CHECKPOINT: int
NEW_ABORTING_CONNECTION: int
DUMP_NOT_IMPLEMENTED: int
FLUSH_MASTER_BINLOG_CLOSED: int
INDEX_REBUILD: int
MASTER: int
MASTER_NET_READ: int
MASTER_NET_WRITE: int
FT_MATCHING_KEY_NOT_FOUND: int
LOCK_OR_ACTIVE_TRANSACTION: int
UNKNOWN_SYSTEM_VARIABLE: int
CRASHED_ON_USAGE: int
CRASHED_ON_REPAIR: int
WARNING_NOT_COMPLETE_ROLLBACK: int
TRANS_CACHE_FULL: int
SLAVE_MUST_STOP: int
SLAVE_NOT_RUNNING: int
BAD_SLAVE: int
MASTER_INFO: int
SLAVE_THREAD: int
TOO_MANY_USER_CONNECTIONS: int
SET_CONSTANTS_ONLY: int
LOCK_WAIT_TIMEOUT: int
LOCK_TABLE_FULL: int
READ_ONLY_TRANSACTION: int
DROP_DB_WITH_READ_LOCK: int
CREATE_DB_WITH_READ_LOCK: int
WRONG_ARGUMENTS: int
NO_PERMISSION_TO_CREATE_USER: int
UNION_TABLES_IN_DIFFERENT_DIR: int
LOCK_DEADLOCK: int
TABLE_CANT_HANDLE_FT: int
CANNOT_ADD_FOREIGN: int
NO_REFERENCED_ROW: int
ROW_IS_REFERENCED: int
CONNECT_TO_MASTER: int
QUERY_ON_MASTER: int
ERROR_WHEN_EXECUTING_COMMAND: int
WRONG_USAGE: int
WRONG_NUMBER_OF_COLUMNS_IN_SELECT: int
CANT_UPDATE_WITH_READLOCK: int
MIXING_NOT_ALLOWED: int
DUP_ARGUMENT: int
USER_LIMIT_REACHED: int
SPECIFIC_ACCESS_DENIED_ERROR: int
LOCAL_VARIABLE: int
GLOBAL_VARIABLE: int
NO_DEFAULT: int
WRONG_VALUE_FOR_VAR: int
WRONG_TYPE_FOR_VAR: int
VAR_CANT_BE_READ: int
CANT_USE_OPTION_HERE: int
NOT_SUPPORTED_YET: int
MASTER_FATAL_ERROR_READING_BINLOG: int
SLAVE_IGNORED_TABLE: int
INCORRECT_GLOBAL_LOCAL_VAR: int
WRONG_FK_DEF: int
KEY_REF_DO_NOT_MATCH_TABLE_REF: int
OPERAND_COLUMNS: int
SUBQUERY_NO_1_ROW: int
UNKNOWN_STMT_HANDLER: int
CORRUPT_HELP_DB: int
CYCLIC_REFERENCE: int
AUTO_CONVERT: int
ILLEGAL_REFERENCE: int
DERIVED_MUST_HAVE_ALIAS: int
SELECT_REDUCED: int
TABLENAME_NOT_ALLOWED_HERE: int
NOT_SUPPORTED_AUTH_MODE: int
SPATIAL_CANT_HAVE_NULL: int
COLLATION_CHARSET_MISMATCH: int
SLAVE_WAS_RUNNING: int
SLAVE_WAS_NOT_RUNNING: int
TOO_BIG_FOR_UNCOMPRESS: int
ZLIB_Z_MEM_ERROR: int
ZLIB_Z_BUF_ERROR: int
ZLIB_Z_DATA_ERROR: int
CUT_VALUE_GROUP_CONCAT: int
WARN_TOO_FEW_RECORDS: int
WARN_TOO_MANY_RECORDS: int
WARN_NULL_TO_NOTNULL: int
WARN_DATA_OUT_OF_RANGE: int
WARN_DATA_TRUNCATED: int
WARN_USING_OTHER_HANDLER: int
CANT_AGGREGATE_2COLLATIONS: int
DROP_USER: int
REVOKE_GRANTS: int
CANT_AGGREGATE_3COLLATIONS: int
CANT_AGGREGATE_NCOLLATIONS: int
VARIABLE_IS_NOT_STRUCT: int
UNKNOWN_COLLATION: int
SLAVE_IGNORED_SSL_PARAMS: int
SERVER_IS_IN_SECURE_AUTH_MODE: int
WARN_FIELD_RESOLVED: int
BAD_SLAVE_UNTIL_COND: int
MISSING_SKIP_SLAVE: int
UNTIL_COND_IGNORED: int
WRONG_NAME_FOR_INDEX: int
WRONG_NAME_FOR_CATALOG: int
WARN_QC_RESIZE: int
BAD_FT_COLUMN: int
UNKNOWN_KEY_CACHE: int
WARN_HOSTNAME_WONT_WORK: int
UNKNOWN_STORAGE_ENGINE: int
WARN_DEPRECATED_SYNTAX: int
NON_UPDATABLE_TABLE: int
FEATURE_DISABLED: int
OPTION_PREVENTS_STATEMENT: int
DUPLICATED_VALUE_IN_TYPE: int
TRUNCATED_WRONG_VALUE: int
TOO_MUCH_AUTO_TIMESTAMP_COLS: int
INVALID_ON_UPDATE: int
UNSUPPORTED_PS: int
GET_ERRMSG: int
GET_TEMPORARY_ERRMSG: int
UNKNOWN_TIME_ZONE: int
WARN_INVALID_TIMESTAMP: int
INVALID_CHARACTER_STRING: int
WARN_ALLOWED_PACKET_OVERFLOWED: int
CONFLICTING_DECLARATIONS: int
SP_NO_RECURSIVE_CREATE: int
SP_ALREADY_EXISTS: int
SP_DOES_NOT_EXIST: int
SP_DROP_FAILED: int
SP_STORE_FAILED: int
SP_LILABEL_MISMATCH: int
SP_LABEL_REDEFINE: int
SP_LABEL_MISMATCH: int
SP_UNINIT_VAR: int
SP_BADSELECT: int
SP_BADRETURN: int
SP_BADSTATEMENT: int
UPDATE_LOG_DEPRECATED_IGNORED: int
UPDATE_LOG_DEPRECATED_TRANSLATED: int
QUERY_INTERRUPTED: int
SP_WRONG_NO_OF_ARGS: int
SP_COND_MISMATCH: int
SP_NORETURN: int
SP_NORETURNEND: int
SP_BAD_CURSOR_QUERY: int
SP_BAD_CURSOR_SELECT: int
SP_CURSOR_MISMATCH: int
SP_CURSOR_ALREADY_OPEN: int
SP_CURSOR_NOT_OPEN: int
SP_UNDECLARED_VAR: int
SP_WRONG_NO_OF_FETCH_ARGS: int
SP_FETCH_NO_DATA: int
SP_DUP_PARAM: int
SP_DUP_VAR: int
SP_DUP_COND: int
SP_DUP_CURS: int
SP_CANT_ALTER: int
SP_SUBSELECT_NYI: int
STMT_NOT_ALLOWED_IN_SF_OR_TRG: int
SP_VARCOND_AFTER_CURSHNDLR: int
SP_CURSOR_AFTER_HANDLER: int
SP_CASE_NOT_FOUND: int
FPARSER_TOO_BIG_FILE: int
FPARSER_BAD_HEADER: int
FPARSER_EOF_IN_COMMENT: int
FPARSER_ERROR_IN_PARAMETER: int
FPARSER_EOF_IN_UNKNOWN_PARAMETER: int
VIEW_NO_EXPLAIN: int
FRM_UNKNOWN_TYPE: int
WRONG_OBJECT: int
NONUPDATEABLE_COLUMN: int
VIEW_SELECT_DERIVED: int
VIEW_SELECT_CLAUSE: int
VIEW_SELECT_VARIABLE: int
VIEW_SELECT_TMPTABLE: int
VIEW_WRONG_LIST: int
WARN_VIEW_MERGE: int
WARN_VIEW_WITHOUT_KEY: int
VIEW_INVALID: int
SP_NO_DROP_SP: int
SP_GOTO_IN_HNDLR: int
TRG_ALREADY_EXISTS: int
TRG_DOES_NOT_EXIST: int
TRG_ON_VIEW_OR_TEMP_TABLE: int
TRG_CANT_CHANGE_ROW: int
TRG_NO_SUCH_ROW_IN_TRG: int
NO_DEFAULT_FOR_FIELD: int
DIVISION_BY_ZERO: int
TRUNCATED_WRONG_VALUE_FOR_FIELD: int
ILLEGAL_VALUE_FOR_TYPE: int
VIEW_NONUPD_CHECK: int
VIEW_CHECK_FAILED: int
PROCACCESS_DENIED_ERROR: int
RELAY_LOG_FAIL: int
PASSWD_LENGTH: int
UNKNOWN_TARGET_BINLOG: int
IO_ERR_LOG_INDEX_READ: int
BINLOG_PURGE_PROHIBITED: int
FSEEK_FAIL: int
BINLOG_PURGE_FATAL_ERR: int
LOG_IN_USE: int
LOG_PURGE_UNKNOWN_ERR: int
RELAY_LOG_INIT: int
NO_BINARY_LOGGING: int
RESERVED_SYNTAX: int
WSAS_FAILED: int
DIFF_GROUPS_PROC: int
NO_GROUP_FOR_PROC: int
ORDER_WITH_PROC: int
LOGGING_PROHIBIT_CHANGING_OF: int
NO_FILE_MAPPING: int
WRONG_MAGIC: int
PS_MANY_PARAM: int
KEY_PART_0: int
VIEW_CHECKSUM: int
VIEW_MULTIUPDATE: int
VIEW_NO_INSERT_FIELD_LIST: int
VIEW_DELETE_MERGE_VIEW: int
CANNOT_USER: int
XAER_NOTA: int
XAER_INVAL: int
XAER_RMFAIL: int
XAER_OUTSIDE: int
XAER_RMERR: int
XA_RBROLLBACK: int
NONEXISTING_PROC_GRANT: int
PROC_AUTO_GRANT_FAIL: int
PROC_AUTO_REVOKE_FAIL: int
DATA_TOO_LONG: int
SP_BAD_SQLSTATE: int
STARTUP: int
LOAD_FROM_FIXED_SIZE_ROWS_TO_VAR: int
CANT_CREATE_USER_WITH_GRANT: int
WRONG_VALUE_FOR_TYPE: int
TABLE_DEF_CHANGED: int
SP_DUP_HANDLER: int
SP_NOT_VAR_ARG: int
SP_NO_RETSET: int
CANT_CREATE_GEOMETRY_OBJECT: int
FAILED_ROUTINE_BREAK_BINLOG: int
BINLOG_UNSAFE_ROUTINE: int
BINLOG_CREATE_ROUTINE_NEED_SUPER: int
EXEC_STMT_WITH_OPEN_CURSOR: int
STMT_HAS_NO_OPEN_CURSOR: int
COMMIT_NOT_ALLOWED_IN_SF_OR_TRG: int
NO_DEFAULT_FOR_VIEW_FIELD: int
SP_NO_RECURSION: int
TOO_BIG_SCALE: int
TOO_BIG_PRECISION: int
M_BIGGER_THAN_D: int
WRONG_LOCK_OF_SYSTEM_TABLE: int
CONNECT_TO_FOREIGN_DATA_SOURCE: int
QUERY_ON_FOREIGN_DATA_SOURCE: int
FOREIGN_DATA_SOURCE_DOESNT_EXIST: int
FOREIGN_DATA_STRING_INVALID_CANT_CREATE: int
FOREIGN_DATA_STRING_INVALID: int
CANT_CREATE_FEDERATED_TABLE: int
TRG_IN_WRONG_SCHEMA: int
STACK_OVERRUN_NEED_MORE: int
TOO_LONG_BODY: int
WARN_CANT_DROP_DEFAULT_KEYCACHE: int
TOO_BIG_DISPLAYWIDTH: int
XAER_DUPID: int
DATETIME_FUNCTION_OVERFLOW: int
CANT_UPDATE_USED_TABLE_IN_SF_OR_TRG: int
VIEW_PREVENT_UPDATE: int
PS_NO_RECURSION: int
SP_CANT_SET_AUTOCOMMIT: int
MALFORMED_DEFINER: int
VIEW_FRM_NO_USER: int
VIEW_OTHER_USER: int
NO_SUCH_USER: int
FORBID_SCHEMA_CHANGE: int
ROW_IS_REFERENCED_2: int
NO_REFERENCED_ROW_2: int
SP_BAD_VAR_SHADOW: int
TRG_NO_DEFINER: int
OLD_FILE_FORMAT: int
SP_RECURSION_LIMIT: int
SP_PROC_TABLE_CORRUPT: int
SP_WRONG_NAME: int
TABLE_NEEDS_UPGRADE: int
SP_NO_AGGREGATE: int
MAX_PREPARED_STMT_COUNT_REACHED: int
VIEW_RECURSIVE: int
NON_GROUPING_FIELD_USED: int
TABLE_CANT_HANDLE_SPKEYS: int
NO_TRIGGERS_ON_SYSTEM_SCHEMA: int
USERNAME: int
HOSTNAME: int
WRONG_STRING_LENGTH: int
ERROR_LAST: int
